@@ -327,7 +327,7 @@ ppd_selection_dialog_response_cb (GtkDialog *dialog,
 PpPPDSelectionDialog *
 pp_ppd_selection_dialog_new (GtkWindow            *parent,
                              PPDList              *ppd_list,
-                             gchar                *manufacturer,
+                             const gchar          *manufacturer,
                              UserResponseCallback  user_callback,
                              gpointer              user_data)
 {
